pub fn classify(events: &[Value]) -> JsonlStateExpand description
Classify a turn from the transcript events alone (PoC 3.4, with the later-user refinement).
pub fn classify(events: &[Value]) -> JsonlStateClassify a turn from the transcript events alone (PoC 3.4, with the later-user refinement).